arrayContains property
Creates a new filter for checking that the given array field contains the given value.
Implementation
final Object? arrayContains;
Creates a new filter for checking that the given array field contains the given value.
final Object? arrayContains;