arrayContainsAny property

Iterable<Object?>? arrayContainsAny
final

Creates a new filter for checking that the given array field contains any of the given values.

Implementation

final Iterable<Object?>? arrayContainsAny;