isEqualTo property
Creates a new filter for checking that the given field is equal to the given value.
Implementation
final Object? isEqualTo;
Creates a new filter for checking that the given field is equal to the given value.
final Object? isEqualTo;