isGreaterThan property
Creates a new filter for checking that the given field is greater than the given value.
Implementation
final Object? isGreaterThan;
Creates a new filter for checking that the given field is greater than the given value.
final Object? isGreaterThan;