isGreaterThanOrEqualTo property

Object? isGreaterThanOrEqualTo
final

Creates a new filter for checking that the given field is greater than or equal to the given value.

Implementation

final Object? isGreaterThanOrEqualTo;