isLessThan property
Creates a new filter for checking that the given field is less than the given value.
Implementation
final Object? isLessThan;
Creates a new filter for checking that the given field is less than the given value.
final Object? isLessThan;