isNotEqualTo property
Creates a new filter for checking that the given field is not equal to the given value.
Implementation
final Object? isNotEqualTo;
Creates a new filter for checking that the given field is not equal to the given value.
final Object? isNotEqualTo;