whereNotIn property

Iterable<Object?>? whereNotIn
final

Creates a new filter for checking that the given field does not equal any of the given values.

Implementation

final Iterable<Object?>? whereNotIn;