FilterWrapper class

Constructors

FilterWrapper({required String collection, required List<DataFilter> itemsQuery, required DataFilter itemGet, String? subCollection})

Properties

collection String
final
hashCode int
The hash code for this object.
no setterinherited
itemGet DataFilter
final
itemsQuery List<DataFilter>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subCollection String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited