IDatabasePlatform<T extends BaseObject> class abstract

Constructors

IDatabasePlatform({required FilterWrapper filterWrapper, required ItemCreator<T> creator})

Properties

creator ItemCreator<T>
final
filterWrapper FilterWrapper
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createItem(T item) Future<Result<int, String, T>>
deleteItem(String id) Future<Result<int, String, T?>>
getItem({String? id, dynamic docRef}) Future<Result<int, String, T?>>
getItems({List<DataFilter>? subCollectionQuery, bool? useCursor, bool getCount = false, int limit = limit}) Future<Result<int, String, List<T>>>
getWholeCollection({required int currentCount, List<DataFilter>? subCollectionQuery, int limit = limit}) Future<Result<int, String, List<T>>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setItem(T item) Future<Result<int, String, T>>
toString() String
A string representation of this object.
inherited
updateFields(String id, Map<String, dynamic> map) Future<Result<int, String, T?>>
updateItem(T item) Future<Result<int, String, T>>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

limit → const int