PhotoPicker class
Constructors
- PhotoPicker({required Function onSelection, required BuildContext context})
-
const
Properties
- context → BuildContext
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onSelection → Function
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getMapOptions(
) → List< Map< String, dynamic> > -
getPhotoPickerOptions(
BuildContext context) → List< Widget> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
show(
String selectOption) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited