DataFilter class
Constructors
-
DataFilter(Object field, {Object? isEqualTo, Object? isNotEqualTo, Object? isLessThan, Object? isLessThanOrEqualTo, Object? isGreaterThan, Object? isGreaterThanOrEqualTo, Object? arrayContains, Iterable<Object?>? arrayContainsAny, Iterable<Object?>? whereIn, Iterable<Object?>? whereNotIn, bool? isNull})
-
Properties
-
arrayContains
→ Object?
-
Creates a new filter for checking that the given array field contains the given value.
final
-
arrayContainsAny
→ Iterable<Object?>?
-
Creates a new filter for checking that the given array field contains any of the given values.
final
-
field
→ Object
-
The field or
FieldPath to filter on.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
isEqualTo
→ Object?
-
Creates a new filter for checking that the given field is equal to the given value.
final
-
isGreaterThan
→ Object?
-
Creates a new filter for checking that the given field is greater than the given value.
final
-
isGreaterThanOrEqualTo
→ Object?
-
Creates a new filter for checking that the given field is greater than or equal to the given value.
final
-
isLessThan
→ Object?
-
Creates a new filter for checking that the given field is less than the given value.
final
-
isLessThanOrEqualTo
→ Object?
-
Creates a new filter for checking that the given field is less than or equal to the given value.
final
-
isNotEqualTo
→ Object?
-
Creates a new filter for checking that the given field is not equal to the given value.
final
-
isNull
→ bool?
-
Creates a new filter for checking that the given field is null.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
whereIn
→ Iterable<Object?>?
-
Creates a new filter for checking that the given field equals any of the given values.
final
-
whereNotIn
→ Iterable<Object?>?
-
Creates a new filter for checking that the given field does not equal any of the given values.
final
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited