isGreaterThanOrEqualTo property
Creates a new filter for checking that the given field is greater than or equal to the given value.
Implementation
final Object? isGreaterThanOrEqualTo;
Creates a new filter for checking that the given field is greater than or equal to the given value.
final Object? isGreaterThanOrEqualTo;