isLessThanOrEqualTo property
Creates a new filter for checking that the given field is less than or equal to the given value.
Implementation
final Object? isLessThanOrEqualTo;
Creates a new filter for checking that the given field is less than or equal to the given value.
final Object? isLessThanOrEqualTo;